#!/bin/sh
# Copyright 2008 VMware Inc.,

export PATH=/bin:/sbin:/usr/bin:/usr/sbin

: ${INITSCRIPTSDIR:=/etc/vmware/init/init.d}

. /etc/vmware/init/bin/functions.sh

MarkTime()
{
   if [ "${SYSBOOT_TIME}" = "yes" ] ; then
      if [ "${SYSBOOT_QUIET}" = "yes" ] ; then
         echo -n "[$(date +%T.%v)] " >> "${LOGFILE}"
      else
         echo -n "[$(date +%T.%v)] " | tee -a "${LOGFILE}"
      fi

      Begin "Instrumentation"
      End 0
   else
      echo "[$(date +%T.%v)] sysboot: Instrumentation" >> "${LOGFILE}"
   fi
}

if [ -n "${1}" -a -e "${INITSCRIPTSDIR}/${1}" ] ; then
   name="${1##*.}"
   retval=${SUCCESS}

   Begin "${name}"
   . "${INITSCRIPTSDIR}/$1"
   retval=$?
   End ${retval}

   exit ${retval}
fi

# This is too early to use the helper functions.  We must manually check it.
if [ $(echo "$*" | grep -c '+debug') -ge 1 ] ; then
   VERBOSE="no"
   SYSBOOT_QUIET="no"
   SYSBOOT_DEBUG="yes"
fi

if HostType_OSIsPureVMK ; then
   echo "VMKernel Initialization Time: $(esxcfg-init --uptime | tail -n 1)" >> "${LOGFILE}"
fi

for script in $(ls ${INITSCRIPTSDIR} | grep -e '^[0-9]\+\.' | sort -n) ; do
   name="${script##*.}"
   retval=${SUCCESS}

   if [ "${SYSBOOT_TIME}" = "yes" ] ; then
      if [ "${SYSBOOT_QUIET}" = "yes" ] ; then
         echo -n "[$(date +%T.%v)] " >> "${LOGFILE}"
      else
         echo -n "[$(date +%T.%v)] " | tee -a "${LOGFILE}"
      fi
   fi

   Begin "${name}"

   if [ "${SYSBOOT_TIME}" = "yes" ] ; then
      INDENTATION="${INDENTATION}                  "
   fi

   . "${INITSCRIPTSDIR}/${script}"
   retval=$?

   if [ "${SYSBOOT_TIME}" = "yes" ] ; then
      INDENTATION="${INDENTATION%                  }"
   fi

   End ${retval}

   case ${retval} in
      ${SUCCESS})
      ;;
      ${NON_CRITICAL_FAILURE})
         Log "${script} returned non-critical failure"
      ;;
      ${FAILURE})
         Log "${script} returned failure"
      ;;
      ${FATAL_ERROR})
         Log "${script} returned critical failure"
         RecoveryShell
         break
      ;;
      ${HALT})
         Log "${script} requested halt."
         exec /bin/init
      ;;
      *)
         Log "${script} returned unknown error code: ${retval}"
      ;;
   esac
done

MarkTime
